/***************************************************************************
*   KBlocks, a falling blocks game by KDE                                 *
*   SPDX-FileCopyrightText: 2010 University Freiburg <squall.leonhart.cai@gmail.com> *
*                                                                          *
*   SPDX-License-Identifier: GPL-2.0-or-later
***************************************************************************/
#ifndef KBLOCKSAITYPEDEFINE_H
#define KBLOCKSAITYPEDEFINE_H

#include <utility>
#include <stdlib.h>

#define KSIRTET

#define INITLIST

#ifndef DEBUG
#define DEBUG
#endif

#ifndef LOG
#define LOG
#endif

#define UNIX

#endif
